camelot.camelot.model

Package camelot :: Package camelot :: Package model |
[hide private]
[frames] | no frames]

# Source Code for Package camelot.camelot.model

     1  import elixir
     2  from elixir import *
     3  from sqlalchemy import *
     4  from sqlalchemy.orm import scoped_session, create_session
     5

     6  elixir.session = scoped_session(create_session)
     7

     8  import settings
     9

    10  metadata = MetaData()
    11

    12  __metadata__ = metadata
    13

    14  __metadata__.bind = settings.ENGINE()
    15  __metadata__.autoflush = False
    16  __metadata__.transactional = False
    17